@@ -243,7 +243,7 @@ class SelectWidget(widgets.Widget):
 
     def render_option(self, selected_choices, option_value, option_label):
         option_value = force_text(option_value)
-        other_html = (u' selected="selected"'
+        other_html = (' selected="selected"'
                       if option_value in selected_choices else '')
 
         other_html += self.transform_option_html_attrs(option_label)
@@ -254,7 +254,7 @@ class SelectWidget(widgets.Widget):
 
         option_label = self.transform_option_label(option_label)
 
-        return u'<option value="%s"%s>%s</option>' % (
+        return '<option value="%s"%s>%s</option>' % (
             html.escape(option_value), other_html, option_label)
 
     def render_options(self, selected_choices):
@@ -308,6 +308,8 @@ class ThemableSelectWidget(SelectWidget):
 
         new_choices = []
         initial_value = value
+        # Initially assuming value is not present in choices.
+        value_in_choices = False
         for opt_value, opt_label in itertools.chain(self.choices, choices):
             other_html = self.transform_option_html_attrs(opt_label)
 
@@ -318,15 +320,19 @@ class ThemableSelectWidget(SelectWidget):
             opt_label = self.transform_option_label(opt_label)
 
             # If value exists, save off its label for use
+            # and setting value in choices to True
             if opt_value == value:
                 initial_value = opt_label
+                value_in_choices = True
 
             if other_html:
                 new_choices.append((opt_value, opt_label, other_html))
             else:
                 new_choices.append((opt_value, opt_label))
 
-        if value is None and new_choices:
+        # if value is None or it is not present in choices then set
+        # the first value of choices.
+        if (value is None or not value_in_choices) and new_choices:
             initial_value = new_choices[0][1]
 
         attrs = self.build_attrs(attrs)
@@ -424,7 +430,7 @@ class ThemableCheckboxInput(widgets.CheckboxInput):
             label_for = attrs['id']
 
         return html.format_html(
-            u'<div class="themable-checkbox">{}<label for="{}"></label></div>',
+            '<div class="themable-checkbox">{}<label for="{}"></label></div>',
             super().render(name, value, attrs),
             label_for
         )
@@ -538,8 +544,8 @@ class ThemableCheckboxChoiceInput(ChoiceInput):
             label_for = ''
         attrs = dict(self.attrs, **attrs) if attrs else self.attrs
         return html.format_html(
-            u'<div class="themable-checkbox">{}<label{}>' +
-            u'<span>{}</span></label></div>',
+            '<div class="themable-checkbox">{}<label{}>' +
+            '<span>{}</span></label></div>',
             self.tag(attrs), label_for, self.choice_label
         )
 
