@@ -26,7 +26,6 @@ INSTANCES_KEYPAIR = r'^(?P<instance_id>[^/]+)/(?P<keypair_name>[^/]+)/%s$'
 
 urlpatterns = [
     url(r'^$', views.IndexView.as_view(), name='index'),
-    url(r'^launch$', views.LaunchInstanceView.as_view(), name='launch'),
     url(r'^(?P<instance_id>[^/]+)/$',
         views.DetailView.as_view(), name='detail'),
     url(INSTANCES % 'update', views.UpdateView.as_view(), name='update'),
@@ -41,6 +40,8 @@ urlpatterns = [
     url(INSTANCES % 'resize', views.ResizeView.as_view(), name='resize'),
     url(INSTANCES_KEYPAIR % 'decryptpassword',
         views.DecryptPasswordView.as_view(), name='decryptpassword'),
+    url(INSTANCES % 'disassociate',
+        views.DisassociateView.as_view(), name='disassociate'),
     url(INSTANCES % 'attach_interface',
         views.AttachInterfaceView.as_view(), name='attach_interface'),
     url(INSTANCES % 'detach_interface',
@@ -52,5 +53,8 @@ urlpatterns = [
     url(r'^(?P<instance_id>[^/]+)/detach_volume/$',
         views.DetachVolumeView.as_view(),
         name='detach_volume'
-        )
+        ),
+    url(r'^(?P<instance_id>[^/]+)/ports/(?P<port_id>[^/]+)/update$',
+        views.UpdatePortView.as_view(), name='update_port'),
+    url(INSTANCES % 'rescue', views.RescueView.as_view(), name='rescue'),
 ]
