@@ -40,7 +40,6 @@ from horizon import workflows
 
 from openstack_dashboard import api
 from openstack_dashboard.utils import filters
-from openstack_dashboard.utils import settings as setting_utils
 
 from openstack_dashboard.dashboards.project.instances \
     import console as project_console
@@ -50,8 +49,6 @@ from openstack_dashboard.dashboards.project.instances \
     import tables as project_tables
 from openstack_dashboard.dashboards.project.instances \
     import tabs as project_tabs
-from openstack_dashboard.dashboards.project.instances \
-    import utils as instance_utils
 from openstack_dashboard.dashboards.project.instances \
     import workflows as project_workflows
 from openstack_dashboard.dashboards.project.networks.ports \
@@ -262,26 +259,6 @@ def _swap_filter(resources, search_opts, fake_field, real_field):
     return True
 
 
-class LaunchInstanceView(workflows.WorkflowView):
-    workflow_class = project_workflows.LaunchInstance
-
-    def __init__(self):
-        super().__init__()
-        LOG.warning('Django version of the launch instance form is '
-                    'deprecated since Wallaby release. Switch to '
-                    'the AngularJS version of the form by setting '
-                    'LAUNCH_INSTANCE_NG_ENABLED to True and '
-                    'LAUNCH_INSTANCE_LEGACY_ENABLED to False.')
-
-    def get_initial(self):
-        initial = super().get_initial()
-        initial['project_id'] = self.request.user.tenant_id
-        initial['user_id'] = self.request.user.id
-        initial['config_drive'] = setting_utils.get_dict_config(
-            'LAUNCH_INSTANCE_DEFAULTS', 'config_drive')
-        return initial
-
-
 # TODO(stephenfin): Migrate to CBV
 def console(request, instance_id):
     data = _('Unable to get log for instance "%s".') % instance_id
@@ -527,16 +504,9 @@ class DetailView(tabs.TabView):
 
     def _get_flavor(self, instance):
         instance_id = instance.id
-        flavor_id = instance.flavor.get('id')
         try:
-            if flavor_id:  # Nova API <= 2.46
-                instance.full_flavor = api.nova.flavor_get(
-                    self.request, flavor_id)
-            else:
-                flavors = api.nova.flavor_list(self.request)
-                flavor_name_dict = dict((str(f.name), f) for f in flavors)
-                instance.full_flavor = \
-                    flavor_name_dict[instance.flavor['original_name']]
+            instance.full_flavor = api.nova.flavor_get(
+                self.request, instance.flavor["id"])
         except Exception:
             msg = _('Unable to retrieve flavor information for instance '
                     '"%(name)s" (%(id)s).') % {'name': instance.name,
@@ -616,9 +586,19 @@ class ResizeView(workflows.WorkflowView):
             redirect = reverse("horizon:project:instances:index")
             msg = _('Unable to retrieve instance details.')
             exceptions.handle(self.request, msg, redirect=redirect)
+        flavor_id = instance.flavor['id']
         flavors = self.get_flavors()
-        flavor = instance_utils.resolve_flavor(self.request, instance, flavors)
-        instance.flavor_name = flavor.name
+        if flavor_id in flavors:
+            instance.flavor_name = flavors[flavor_id].name
+        else:
+            try:
+                flavor = api.nova.flavor_get(self.request, flavor_id)
+                instance.flavor_name = flavor.name
+            except Exception:
+                msg = _('Unable to retrieve flavor information for instance '
+                        '"%s".') % instance_id
+                exceptions.handle(self.request, msg, ignore=True)
+                instance.flavor_name = _("Not available")
         return instance
 
     @memoized.memoized_method
@@ -639,6 +619,7 @@ class ResizeView(workflows.WorkflowView):
             initial.update(
                 {'instance_id': self.kwargs['instance_id'],
                  'name': getattr(_object, 'name', None),
+                 'old_flavor_id': _object.flavor['id'],
                  'old_flavor_name': getattr(_object, 'flavor_name', ''),
                  'flavors': self.get_flavors()})
         return initial
