@@ -12,7 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
 from django.urls import reverse
 from django.utils.http import urlencode
 from django.utils.translation import ugettext_lazy as _
@@ -76,16 +75,16 @@ class DeleteVolumeSnapshot(policy.PolicyTargetMixin, tables.DeleteAction):
     @staticmethod
     def action_present(count):
         return ungettext_lazy(
-            u"Delete Volume Snapshot",
-            u"Delete Volume Snapshots",
+            "Delete Volume Snapshot",
+            "Delete Volume Snapshots",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ungettext_lazy(
-            u"Scheduled deletion of Volume Snapshot",
-            u"Scheduled deletion of Volume Snapshots",
+            "Scheduled deletion of Volume Snapshot",
+            "Scheduled deletion of Volume Snapshots",
             count
         )
 
@@ -242,11 +241,7 @@ class VolumeDetailsSnapshotsTable(volume_tables.VolumesTableBase):
         prev_pagination_param = 'prev_snapshot_marker'
         table_actions = (VolumeSnapshotsFilterAction, DeleteVolumeSnapshot,)
 
-        launch_actions = ()
-        if settings.LAUNCH_INSTANCE_LEGACY_ENABLED:
-            launch_actions = (LaunchSnapshot,) + launch_actions
-        if settings.LAUNCH_INSTANCE_NG_ENABLED:
-            launch_actions = (LaunchSnapshotNG,) + launch_actions
+        launch_actions = (LaunchSnapshotNG,)
 
         row_actions = ((CreateVolumeFromSnapshot,) + launch_actions +
                        (EditVolumeSnapshot, DeleteVolumeSnapshot, CreateBackup,
