@@ -12,13 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import absolute_import
-
 from django.conf import settings
 from django import template
 
-from openstack_dashboard.api import keystone
-
 
 register = template.Library()
 
@@ -27,9 +23,10 @@ def is_multi_region_configured(request):
     return len(request.user.available_services_regions) > 1
 
 
+# TODO(e0ne): pass OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT to the template
+# context and remove `is_multidomain` template tag
 def is_multidomain_supported():
-    return (keystone.VERSIONS.active >= 3 and
-            settings.OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT)
+    return settings.OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT
 
 
 @register.simple_tag(takes_context=True)
@@ -44,6 +41,15 @@ def is_multidomain():
     return is_multidomain_supported()
 
 
+@register.simple_tag(takes_context=True)
+def is_system_user(context):
+    try:
+        request = context['request']
+    except KeyError:
+        return False
+    return request.user.is_system_user
+
+
 @register.inclusion_tag('context_selection/_overview.html',
                         takes_context=True)
 def show_overview(context):
@@ -58,6 +64,7 @@ def show_overview(context):
                'project_name': project_name or request.user.project_name,
                'multi_region': is_multi_region_configured(request),
                'region_name': request.user.services_region,
+               'system_scoped': request.user.system_scoped,
                'request': request}
 
     return context
@@ -105,6 +112,20 @@ def show_region_list(context):
     return context
 
 
+@register.inclusion_tag('context_selection/_system_list.html',
+                        takes_context=True)
+def show_system_list(context):
+    if 'request' not in context:
+        return {}
+    request = context['request']
+    panel = request.horizon.get('panel')
+    context = {
+        'system_scoped': request.user.system_scoped,
+        'page_url': panel.get_absolute_url() if panel else None,
+    }
+    return context
+
+
 @register.inclusion_tag('context_selection/_anti_clickjack.html',
                         takes_context=True)
 def iframe_embed_settings(context):
